.. include:: /_includes/wip_prolog.rst

:mod:`stix.extensions.test_mechanism.generic_test_mechanism` Module
===================================================================

.. module:: stix.extensions.test_mechanism.generic_test_mechanism

Classes
-------

.. autoclass:: GenericTestMechanism
	:show-inheritance:
	:members:
